@@ -48,7 +48,7 @@ DEBUG:-decotrace-:f(7) -> 14
 14
 """
 
-__VERSION__ = '0.1.4'
+__VERSION__ = '0.1.5'
 
 import sys
 import inspect
@@ -87,7 +87,7 @@ class TraceContext (object):
         def wrapped(wrappedSelf, *args, **kw):
             name = '{0}[@{1:08x}].{2}'.format(
                 wrappedSelf.__class__.__name__,
-                id(self),
+                id(wrappedSelf),
                 m.__name__)
             fullArgs = (wrappedSelf,) + args
             return self._trace_call(name, 1, m, fullArgs, kw)
